MDR69xB Channel - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# MDR69xB Channel

From: Thorlabs

Class: `herosdevices.hardware.thorlabs.mdt69xb.MDT69xBChannel`

Driver Quality Index: beta

A single channel of a MDT69xB piezo driver.

This class provides an `herosdevices.interfaces.atomiq.VoltageSource` compatible interface to control a single channel of a MDT69xB piezo driver.

Note

This class does not directly connect to the hardware but to another object given by the host_device argument which can also be a HERO running on another machine. It can be used to provide a universal interface which does not require setting a channel for every operation.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.thorlabs.mdt69xb.MDT69xBChannel` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
host_device | herosdevices.hardware.thorlabs.mdt69xb.MDT693B | herosdevices.hardware.thorlabs.mdt69xb.MDT694B |  | The host MDT69xB device (MDT693B or MDT694B).
channel | int | str | x | The channel to control (can be int 0-2 or str ‘x’, ‘y’, ‘z’, depending on host_device)

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `MDT69xBChannel` using BOSS.

    {
        "_id": "my-piezo-channel",
        "classname": "herosdevices.hardware.thorlabs.MDT69xBChannel",
        "arguments": {
            "host_device": "$my-3channel-piezo-controller",
            "channel": 1
        }
    }

Note

This example contains a variable that references another HERO with `$`.

from examples/thorlabs/mdt69xb.json

    {
        "_id": "my_MDT69xBChannel",
        "classname": "herosdevices.hardware.thorlabs.mdt69xb.MDT69xBChannel",
        "arguments": {
            "host_device": "herosdevices.hardware.thorlabs.mdt69xb.MDT693B | herosdevices.hardware.thorlabs.mdt69xb.MDT694B",
            "channel": "x"
        }
    }

generated from signature

Inheritance